"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const rpscript_parser_1 = require("rpscript-parser");
const logger_1 = require("../core/logger");
const error_msg_1 = require("../format/error_msg");
const fs_1 = __importDefault(require("fs"));
const R = __importStar(require("../../lib/ramda.min"));
class ExecCommand {
    constructor(config, event) {
        this.runner = new rpscript_parser_1.Runner(config);
        this.debug = config.debug;
        if (!event)
            this.registerDefaultEvents(this.runner);
        else
            event(this.runner);
    }
    run(filename, args = []) {
        return __awaiter(this, void 0, void 0, function* () {
            this.logger = logger_1.Logger.createRunnerLogger(filename, this.debug);
            try {
                let result = yield this.runner.execute(filename, args);
                return result;
            }
            catch (er) {
                console.error(er);
            }
        });
    }
    runStatement(content) {
        return __awaiter(this, void 0, void 0, function* () {
            this.logger = logger_1.Logger.createRunnerLogger('none', this.debug);
            try {
                let result = yield this.runner.execute(null, [], content);
                return result;
            }
            catch (er) {
                console.error(er);
            }
        });
    }
    printParams(params) {
        function genString(p) {
            if (typeof p === 'function')
                return '[function]';
            else if (typeof p === 'object') {
                try {
                    return JSON.stringify(p);
                }
                catch (err) {
                    return "";
                }
            }
            else if (typeof p === 'symbol') {
                return p.toString();
            }
            else
                return p;
        }
        if (Array.isArray(params))
            return R.map(genString, params).join(' , ');
        else
            return genString(params);
    }
    registerDefaultEvents(evtEmt) {
        evtEmt.on(rpscript_parser_1.Runner.COMPILE_START_EVT, params => {
            this.logger.debug('compilation - start for ' + params);
        });
        evtEmt.on(rpscript_parser_1.Runner.COMPILED_EVT, params => {
            this.logger.debug('compilation - completed');
            // console.log(params.transpile);
        });
        evtEmt.on(rpscript_parser_1.Runner.LINT_EVT, params => {
            this.logger.debug('linting - completed');
        });
        evtEmt.on(rpscript_parser_1.Runner.TRANSPILE_EVT, params => {
            // console.log(params.fullContent);
            fs_1.default.writeFileSync('.rpscript/temp.ts', params.fullContent);
            this.logger.debug('transpilation completed. output save to .rpscript/temp.ts');
        });
        evtEmt.on(rpscript_parser_1.Runner.MOD_DISABLED_EVT, params => {
            this.logger.debug('module - disabled ' + params);
        });
        evtEmt.on(rpscript_parser_1.Runner.MOD_LOADED_EVT, params => {
            this.logger.debug('module - loaded ' + params);
        });
        evtEmt.on(rpscript_parser_1.Runner.TRANSPILE_ERR_EVT, params => {
            error_msg_1.ErrorMessage.handleKeywordMessage(params);
        });
        evtEmt.on(rpscript_parser_1.Runner.START_EVT, params => {
            this.logger.debug('start of execution');
        });
        evtEmt.on(rpscript_parser_1.Runner.ACTION_EVT, (args) => {
            let arg = args[0];
            let modName = arg[0], actionName = arg[1], evt = arg[2], params = arg[3];
            this.logger.debug(`action - ${evt} execute : ${this.printParams(params)} `);
            if (evt === 'error') {
                this.logger.error(`ERROR : ${params}`);
            }
        });
        evtEmt.on(rpscript_parser_1.Runner.END_EVT, params => {
            this.logger.debug('end of execution');
        });
        evtEmt.on(rpscript_parser_1.Runner.CTX_PRIOR_SET_EVT, params => {
            this.logger.debug(`Priority set => ${params}`);
        });
    }
    getFileName(filepath) {
        let index = filepath.lastIndexOf('/');
        let dotIndex = filepath.lastIndexOf('.');
        return filepath.substring(index + 1, dotIndex);
    }
    static parseProgramOpts(program) {
        return R.pickBy((v, k) => v !== undefined, {
            outputTS: program.skipOutputTS, linting: program.skipLinting,
            outputDir: program.outputDir, skipRun: program.skipRun,
            debug: program.debug, modules: program.modules
        });
    }
}
exports.ExecCommand = ExecCommand;
