"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const rpscript_parser_1 = require("rpscript-parser");
const cli_table_1 = __importDefault(require("cli-table"));
const R = __importStar(require("../../lib/ramda.min"));
const logger_1 = require("../core/logger");
var pjson = require('../../package.json');
class ModuleCommand {
    constructor() {
        this.modMgr = new rpscript_parser_1.ModuleMgr;
        this.logger = logger_1.Logger.createModuleLogger();
        this.registerDefaultEvents(this.modMgr.event);
    }
    install(allowExternalModule, modName) {
        return __awaiter(this, void 0, void 0, function* () {
            for (var i = 0; i < modName.length; i++) {
                if (!allowExternalModule && !R.contains(this.extractModuleName(modName[i]), pjson.officialModules))
                    this.logger.error(modName[i] + ' is not available.');
                else {
                    this.logger.info('installing module ' + modName[i] + '...');
                    yield this.modMgr.installModule(modName[i], allowExternalModule);
                }
            }
        });
    }
    extractModuleName(modName) {
        let index = modName.indexOf('@');
        if (index > 0)
            return modName.substring(0, index);
        else
            return modName;
    }
    remove(modName) {
        return __awaiter(this, void 0, void 0, function* () {
            for (var i = 0; i < modName.length; i++) {
                this.logger.info('removing module ' + modName[i] + '...');
                this.modMgr.removeModule(modName[i]);
            }
        });
    }
    listInstalledModulesArr() {
        let installedModules = R.keys(R.omit(['$DEFAULT'], this.modMgr.listInstalledModules()));
        return installedModules;
    }
    listInstalledModules() {
        let installedModules = R.values(R.omit(['$DEFAULT'], this.modMgr.listInstalledModules()));
        let table = new cli_table_1.default({ head: ['name', 'version'] });
        // let table = new Table({head: ['name', 'version','enable','description']});
        installedModules.forEach(mod => table.push([mod.name, mod.npmVersion]));
        // installedModules.forEach(mod => table.push([
        //   mod.name, mod.npmVersion, mod.enabled, !mod.description ? '' : mod.description] ));
        return table.toString();
    }
    listInstallModulesJson() {
        let installedModules = this.modMgr.listInstalledModules();
        return JSON.stringify(installedModules, null, 2);
    }
    listAvailableModules() {
        return JSON.stringify(this.modMgr.listAvailableModules());
    }
    listModuleInfo(mod) {
        let iModules = this.modMgr.listInstalledModules();
        let module = iModules[mod];
        if (!module)
            return 'module ' + mod + ' is not installed';
        else {
            // let table = new Table({head:['action','params']});
            // let actions = module.actions;
            // let paramsStr = (paramsArr) => R.pluck( 'name', R.values(paramsArr) ).join(',');
            // var eachAction = (value, key) => {
            //   table.push([value.verbName, paramsStr(value.params)]);
            // };
            // R.forEachObjIndexed(eachAction, actions);
            // let actionsTbl = table.toString();
            let v = R.pluck('verbName', R.values(R.prop('actions')(module)));
            let modName = 'name : ' + module.name;
            let modVersion = 'version : ' + module.npmVersion;
            let allActions = 'actions : ' + v.join(', ');
            return modName + '\n' + modVersion + '\n' + allActions;
        }
    }
    listDefaultKeywords() {
        let defaultMod = this.modMgr.listInstalledModules()['$DEFAULT'];
        let defKeywords = R.keys(defaultMod);
        let table = new cli_table_1.default({ head: ['keyword', 'modules'] });
        let modList = (modActionList) => {
            return R.pluck('moduleName', modActionList).join(',');
        };
        R.forEachObjIndexed((val, key) => {
            table.push([key, modList(val)]);
        }, defaultMod);
        return table.toString();
    }
    registerDefaultEvents(evtEmt) {
        evtEmt.on(rpscript_parser_1.ModuleMgr.MOD_INSTALLED_NPM_EVT, params => {
            this.logger.info('module ' + params.name + ' installed');
            this.logger.info(params.npm.text);
        });
        evtEmt.on(rpscript_parser_1.ModuleMgr.MOD_INSTALLED_CONFIG_EVT, params => {
            this.logger.info('module ' + params.name + ' configured ');
        });
        evtEmt.on(rpscript_parser_1.ModuleMgr.MOD_INSTALLED_ERROR_EVT, params => {
            this.logger.error(params);
        });
        evtEmt.on(rpscript_parser_1.ModuleMgr.MOD_REMOVED_NPM_EVT, params => {
            this.logger.info('module removed : ' + params + '');
        });
        evtEmt.on(rpscript_parser_1.ModuleMgr.MOD_REMOVED_CONFIG_EVT, params => {
            this.logger.info('module ' + params.name + ' removed configuration');
        });
        evtEmt.on(rpscript_parser_1.ModuleMgr.MOD_REMOVED_ERROR_EVT, params => {
            this.logger.error(params);
        });
    }
}
exports.ModuleCommand = ModuleCommand;
