"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const winston_1 = __importDefault(require("winston"));
const fs_1 = __importDefault(require("fs"));
const dateformat_1 = __importDefault(require("dateformat"));
const HOMEDIR = require('os').homedir();
const { combine, timestamp, label, printf } = winston_1.default.format;
const runnerLogFormat = printf(info => {
    return `${info.timestamp} [${info.label}] ${info.level}: ${info.message}`;
});
const moduleLogFormat = printf(info => {
    return `${info.timestamp} ${info.level}: ${info.message}`;
});
class Logger {
    constructor() { }
    static createModuleLogger() {
        let modLogDir = `${process.cwd()}/.rpscript/logs`;
        if (!fs_1.default.existsSync(modLogDir))
            fs_1.default.mkdirSync(modLogDir);
        return winston_1.default.createLogger({
            level: 'debug',
            format: combine(timestamp({ format: 'YYYY-MM-DD HH:mm:ss' }), moduleLogFormat),
            transports: [
                new winston_1.default.transports.File({ filename: `${modLogDir}/module_error.log`, level: 'error' }),
                new winston_1.default.transports.File({ filename: `${modLogDir}/module.log` }),
                new winston_1.default.transports.Console({ format: combine(timestamp({ format: 'YYYY-MM-DD HH:mm:ss' }), moduleLogFormat) })
            ]
        });
    }
    static createRunnerLogger(fileName, debug) {
        let modLogDir = `${process.cwd()}/.rpscript/logs`;
        if (!fs_1.default.existsSync(modLogDir))
            fs_1.default.mkdirSync(modLogDir);
        let runnerLogDir = `${process.cwd()}/.rpscript/logs/runner/`;
        if (!fs_1.default.existsSync(runnerLogDir))
            fs_1.default.mkdirSync(runnerLogDir);
        let logFile = dateformat_1.default('yy-mm-dd-HH-MM-ss') + '-run.log';
        if (!fs_1.default.existsSync(runnerLogDir))
            fs_1.default.mkdirSync(runnerLogDir);
        let level = debug ? 'debug' : 'info';
        let log = winston_1.default.createLogger({
            level: level,
            format: combine(label({ label: fileName }), timestamp({ format: 'YYYY-MM-DD HH:mm:ss' }), runnerLogFormat),
            transports: [
                new winston_1.default.transports.File({ filename: `${runnerLogDir}/${logFile}` })
            ]
        });
        // if(debug){
        log.add(new winston_1.default.transports.Console({ format: combine(timestamp({ format: 'YYYY-MM-DD HH:mm:ss' }), moduleLogFormat) }));
        // }
        return log;
    }
}
exports.Logger = Logger;
