#! /usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = __importDefault(require("commander"));
const R = __importStar(require("../lib/ramda.min"));
const fs_1 = __importDefault(require("fs"));
const version_1 = require("./commands/version");
const HOMEDIR = require('os').homedir();
commander_1.default
    .option("-v, --version", "Display version", () => {
    let v = new version_1.VersionCommand();
    console.log(v.getVersions());
})
    // .option('-o, --skipOutputTS', 'Output Typescript file')
    // .option('-l, --skipLinting', 'Lint Output Typescript file')
    // .option('-s, --skipRun', 'Skip running the program')
    // .option('-d, --outputDir <path>', 'Working directory path for logs and temp files')
    .description('******************************************** ' + '\n' +
    "   ____  ____    ____            _       _" + '\n' +
    "  |  _ \\\|  _ \\  / ___|  ___ _ __(_)_ __ | |_ " + '\n' +
    "  | |_) | |_) | \\___ \\ / __| '__| | '_ \\| __|" + '\n' +
    "  |  _ <|  __/   ___) | (__| |  | | |_) | |_ " + '\n' +
    "  |_| \\_\\_|     |____/ \\___|_|  |_| .__/ \\__|" + '\n' +
    "                                  |_|         " + '\n' +
    '  ******************************************** ')
    .usage('[filename] [options]');
commander_1.default
    .option('-d, --debug', 'Show debugging information on console')
    .command('verify <filename>', 'Verify if the rps script is valid')
    .command('install [modules]', 'Install one or more modules')
    .command('remove [modules]', 'Remove one or more modules')
    .command('modules', 'List modules information')
    .command('module <module>', 'Show module information')
    .command('actions', 'List installed actions');
//modules <module>  --installed --available
//actions  <action> --defaults  
//enable  <name> --module --action
//disable <name> --module --action
dirSetup();
commander_1.default.parse(process.argv);
let filename = undefined;
let hasRpsFile = R.any(arg => arg.indexOf('.rps') > 0, process.argv);
if (process.argv.length < 3) {
    commander_1.default.help();
}
else if (process.argv[2].indexOf('.rps') > 0) {
    Promise.resolve().then(() => __importStar(require(`${__dirname}/commands/exec`))).then(mod => {
        let ExecCommand = mod['ExecCommand'];
        let command = new ExecCommand(ExecCommand.parseProgramOpts(commander_1.default));
        filename = process.argv[2];
        let args = process.argv.slice(3);
        args = args.filter(a => !a.startsWith('-'));
        command.run(filename, args);
    });
}
else if (!hasRpsFile && commander_1.default.exec) {
    Promise.resolve().then(() => __importStar(require(`${__dirname}/commands/exec`))).then(mod => {
        let ExecCommand = mod['ExecCommand'];
        let command = new ExecCommand(ExecCommand.parseProgramOpts(commander_1.default));
        let commands = process.argv;
        commands = commands.join(' ');
        let exeCom = "";
        let indexOfFlag = commands.lastIndexOf('--exec');
        if (indexOfFlag > 0)
            exeCom = commands.substring(indexOfFlag + 7);
        else {
            indexOfFlag = commands.lastIndexOf('-e');
            if (indexOfFlag > 0)
                exeCom = commands.substring(indexOfFlag + 3);
        }
        command.runStatement(exeCom);
    });
    // console.log('an extension .rps is required for filename');
}
process.on('unhandledRejection', (reason, promise) => {
    console.log('RPscript : Unhandled Rejection at:', reason.stack || reason);
    // Recommended: send the information to sentry.io
    // or whatever crash reporting service you use
});
function dirSetup() {
    let config = {
        outputDir: '.rpscript'
    };
    if (!fs_1.default.existsSync(config['outputDir'])) {
        fs_1.default.mkdirSync(config['outputDir']);
        fs_1.default.mkdirSync(config['outputDir'] + '/logs');
    }
    if (!fs_1.default.existsSync(`${HOMEDIR}/.rpscript/modules/node_modules`)) {
        console.log('ALERT: No module detected.');
        console.log("Please install the basic module with the command 'rps install basic ramda'");
    }
}
